@@ -17,7 +17,7 @@
 
 package Lemonldap::NG::Manager::Build::Tree;
 
-our $VERSION = '2.0.16';
+our $VERSION = '2.16.1';
 
 sub tree {
     return [ {
@@ -66,8 +66,7 @@ sub tree {
                                         'portalCheckLogins',
                                         'portalDisplayRegister',
                                         'portalDisplayCertificateResetByMail',
-                                        'portalDisplayResetPassword',
-                                        'passwordResetAllowedRetries'
+                                        'portalDisplayResetPassword'
                                     ]
                                 },
                                 {
@@ -476,6 +475,15 @@ sub tree {
                     title => 'issuerParams',
                     help  => 'start.html#identity-provider',
                     nodes => [ {
+                            title => 'issuerDBCAS',
+                            help  => 'idpcas.html#enabling-cas',
+                            form  => 'simpleInputContainer',
+                            nodes => [
+                                'issuerDBCASActivation', 'issuerDBCASPath',
+                                'issuerDBCASRule',
+                            ]
+                        },
+                        {
                             title => 'issuerDBSAML',
                             help  => 'idpsaml.html',
                             form  => 'simpleInputContainer',
@@ -485,12 +493,13 @@ sub tree {
                             ]
                         },
                         {
-                            title => 'issuerDBCAS',
-                            help  => 'idpcas.html#enabling-cas',
+                            title => 'issuerDBOpenIDConnect',
+                            help  => 'idpopenidconnect.html',
                             form  => 'simpleInputContainer',
                             nodes => [
-                                'issuerDBCASActivation', 'issuerDBCASPath',
-                                'issuerDBCASRule',
+                                'issuerDBOpenIDConnectActivation',
+                                'issuerDBOpenIDConnectPath',
+                                'issuerDBOpenIDConnectRule',
                             ]
                         },
                         {
@@ -525,16 +534,6 @@ sub tree {
                                 }
                             ]
                         },
-                        {
-                            title => 'issuerDBOpenIDConnect',
-                            help  => 'idpopenidconnect.html',
-                            form  => 'simpleInputContainer',
-                            nodes => [
-                                'issuerDBOpenIDConnectActivation',
-                                'issuerDBOpenIDConnectPath',
-                                'issuerDBOpenIDConnectRule',
-                            ]
-                        },
                         {
                             title => 'issuerDBGet',
                             help  => 'issuerdbget.html',
@@ -619,21 +618,14 @@ sub tree {
                     title => 'plugins',
                     help  => 'start.html#plugins',
                     nodes => [
-                        'portalStatus',
                         'upgradeSession',
                         'refreshSessions',
-                        'adaptativeAuthenticationLevelRules',
+                        'portalStatus',
                         {
-                            title => 'stayConnect',
-                            help  => 'stayconnected.html',
+                            title => 'stateCheck',
+                            help  => 'checkstate.html',
                             form  => 'simpleInputContainer',
-                            nodes => [
-                                'stayConnected',
-                                'stayConnectedBypassFG',
-                                'stayConnectedTimeout',
-                                'stayConnectedCookieName',
-                                'stayConnectedSingleSession',
-                            ],
+                            nodes => [ 'checkState', 'checkStateSecret', ],
                         },
                         {
                             title => 'portalServers',
@@ -666,6 +658,116 @@ sub tree {
                                 },
                             ]
                         },
+                        {
+                            title => 'register',
+                            help  => 'register.html',
+                            nodes => [ {
+                                    title => 'mailContent',
+                                    form  => 'simpleInputContainer',
+                                    nodes => [
+                                        'registerConfirmSubject',
+                                        'registerConfirmBody',
+                                        'registerDoneSubject',
+                                        'registerDoneBody'
+                                    ]
+                                },
+                                {
+                                    title => 'mailOther',
+                                    form  => 'simpleInputContainer',
+                                    nodes =>
+                                      [ 'registerUrl', 'registerTimeout' ]
+                                }
+                            ]
+                        },
+                        {
+                            title => 'passwordManagement',
+                            help  => 'resetpassword.html',
+                            nodes => [ {
+                                    title => 'mailContent',
+                                    form  => 'simpleInputContainer',
+                                    nodes => [
+                                        'mailSubject',
+                                        'mailBody',
+                                        'mailConfirmSubject',
+                                        'mailConfirmBody'
+                                    ]
+                                },
+                                {
+                                    title => 'mailOther',
+                                    form  => 'simpleInputContainer',
+                                    nodes => [
+                                        'mailUrl',
+                                        'mailTimeout',
+                                        'passwordResetAllowedRetries',
+                                        'portalDisplayGeneratePassword',
+                                        'randomPasswordRegexp'
+                                    ]
+                                }
+                            ]
+                        },
+                        {
+                            title => 'certificateResetByMailManagement',
+                            help  => 'resetcertificate.html',
+                            nodes => [ {
+                                    title => 'mailContent',
+                                    form  => 'simpleInputContainer',
+                                    nodes => [
+                                        'certificateResetByMailStep1Subject',
+                                        'certificateResetByMailStep1Body',
+                                        'certificateResetByMailStep2Subject',
+                                        'certificateResetByMailStep2Body'
+                                    ]
+                                },
+                                {
+                                    title => 'mailOther',
+                                    form  => 'simpleInputContainer',
+                                    nodes => [
+                                        'certificateResetByMailURL',
+                                        'certificateResetByMailCeaAttribute',
+'certificateResetByMailCertificateAttribute',
+                                        'certificateResetByMailValidityDelay'
+                                    ]
+                                }
+                            ]
+                        },
+                        'adaptativeAuthenticationLevelRules',
+                        'autoSigninRules',
+                        {
+                            title => 'stayConnect',
+                            help  => 'stayconnected.html',
+                            form  => 'simpleInputContainer',
+                            nodes => [
+                                'stayConnected',
+                                'stayConnectedBypassFG',
+                                'stayConnectedTimeout',
+                                'stayConnectedCookieName',
+                                'stayConnectedSingleSession',
+                            ],
+                        },
+                        {
+                            title => 'rememberAuthChoice',
+                            help  => 'rememberauthchoice.html',
+                            form  => 'simpleInputContainer',
+                            nodes => [
+                                'rememberAuthChoiceRule',
+                                'rememberCookieName',
+                                'rememberCookieTimeout',
+                                'rememberDefaultChecked',
+                                'rememberTimer',
+                            ]
+                        },
+                        {
+                            title => 'locationDetectPlugin',
+                            help  => 'locationdetect.html',
+                            form  => 'simpleInputContainer',
+                            nodes => [
+                                'locationDetect',
+                                'locationDetectGeoIpDatabase',
+                                'locationDetectGeoIpLanguages',
+                                'locationDetectIpDetail',
+                                'locationDetectUaDetail'
+                            ]
+                        },
                         {
                             title => 'loginHistory',
                             help  => 'loginhistory.html',
@@ -709,91 +811,6 @@ sub tree {
                                 },
                             ]
                         },
-                        {
-                            title => 'passwordManagement',
-                            help  => 'resetpassword.html',
-                            nodes => [ {
-                                    title => 'mailContent',
-                                    form  => 'simpleInputContainer',
-                                    nodes => [
-                                        'mailSubject',
-                                        'mailBody',
-                                        'mailConfirmSubject',
-                                        'mailConfirmBody'
-                                    ]
-                                },
-                                {
-                                    title => 'mailOther',
-                                    form  => 'simpleInputContainer',
-                                    nodes => [
-                                        'mailUrl',
-                                        'mailTimeout',
-                                        'portalDisplayGeneratePassword',
-                                        'randomPasswordRegexp',
-                                    ]
-                                }
-                            ]
-                        },
-                        {
-                            title => 'certificateResetByMailManagement',
-                            help  => 'resetcertificate.html',
-                            nodes => [ {
-                                    title => 'certificateMailContent',
-                                    form  => 'simpleInputContainer',
-                                    nodes => [
-                                        'certificateResetByMailStep1Subject',
-                                        'certificateResetByMailStep1Body',
-                                        'certificateResetByMailStep2Subject',
-                                        'certificateResetByMailStep2Body'
-                                    ]
-                                },
-
-                                {
-                                    title => 'mailOther',
-                                    form  => 'simpleInputContainer',
-                                    nodes => [
-                                        'certificateResetByMailURL',
-                                        'certificateResetByMailCeaAttribute',
-'certificateResetByMailCertificateAttribute',
-                                        'certificateResetByMailValidityDelay'
-                                    ]
-                                }
-                            ]
-                        },
-                        {
-                            title => 'register',
-                            help  => 'register.html',
-                            form  => 'simpleInputContainer',
-                            nodes => [
-                                'registerUrl',
-                                'registerTimeout',
-                                'registerConfirmSubject',
-                                'registerConfirmBody',
-                                'registerDoneSubject',
-                                'registerDoneBody'
-                            ]
-                        },
-                        {
-                            title => 'autoSignin',
-                            help  => 'autosignin.html',
-                            nodes => ['autoSigninRules'],
-                        },
-                        {
-                            title => 'globalLogout',
-                            help  => 'globallogout.html',
-                            form  => 'simpleInputContainer',
-                            nodes => [
-                                'globalLogoutRule',
-                                'globalLogoutTimer',
-                                'globalLogoutCustomParam'
-                            ],
-                        },
-                        {
-                            title => 'stateCheck',
-                            help  => 'checkstate.html',
-                            form  => 'simpleInputContainer',
-                            nodes => [ 'checkState', 'checkStateSecret', ],
-                        },
                         {
                             title => 'checkUsers',
                             help  => 'checkuser.html',
@@ -831,16 +848,6 @@ sub tree {
                                 'checkDevOpsCheckSessionAttributes'
                             ],
                         },
-                        {
-                            title => 'HIBPcheck',
-                            help  => 'checkhibp.html',
-                            form  => 'simpleInputContainer',
-                            nodes => [
-                                'checkHIBP',
-                                'checkHIBPURL',
-                                'checkHIBPRequired'
-                            ],
-                        },
                         {
                             title => 'impersonation',
                             help  => 'impersonation.html',
@@ -854,18 +861,6 @@ sub tree {
                                 'impersonationMergeSSOgroups'
                             ]
                         },
-                        {
-                            title => 'findUsers',
-                            help  => 'finduser.html',
-                            nodes => [
-                                'findUser',
-                                'findUserWildcard',
-                                'findUserControl',
-                                'restFindUserDBUrl',
-                                'findUserSearchingAttributes',
-                                'findUserExcludingAttributes'
-                            ]
-                        },
                         {
                             title => 'contextSwitching',
                             help  => 'contextswitching.html',
@@ -879,30 +874,27 @@ sub tree {
                             ]
                         },
                         {
-                            title => 'rememberAuthChoice',
-                            help  => 'rememberauthchoice.html',
-                            form  => 'simpleInputContainer',
+                            title => 'findUsers',
+                            help  => 'finduser.html',
                             nodes => [
-                                'rememberAuthChoiceRule',
-                                'rememberCookieName',
-                                'rememberCookieTimeout',
-                                'rememberDefaultChecked',
-                                'rememberTimer',
+                                'findUser',
+                                'findUserWildcard',
+                                'findUserControl',
+                                'restFindUserDBUrl',
+                                'findUserSearchingAttributes',
+                                'findUserExcludingAttributes'
                             ]
                         },
                         {
-                            title => 'locationDetectPlugin',
-                            help  => 'locationdetect.html',
+                            title => 'globalLogout',
+                            help  => 'globallogout.html',
                             form  => 'simpleInputContainer',
                             nodes => [
-                                'locationDetect',
-                                'locationDetectGeoIpDatabase',
-                                'locationDetectGeoIpLanguages',
-                                'locationDetectIpDetail',
-                                'locationDetectUaDetail'
-                            ]
+                                'globalLogoutRule',
+                                'globalLogoutTimer',
+                                'globalLogoutCustomParam'
+                            ],
                         },
-
                         {
                             title => 'decryptValue',
                             help  => 'decryptvalue.html',
@@ -926,20 +918,6 @@ sub tree {
                         'sfOnlyUpgrade',
                         'sfLoginTimeout',
                         'sfRegisterTimeout',
-                        {
-                            title => 'password2f',
-                            help  => 'password2f.html',
-                            form  => 'simpleInputContainer',
-                            nodes => [
-                                'password2fActivation',
-                                'password2fSelfRegistration',
-                                'password2fAuthnLevel',
-                                'password2fLabel',
-                                'password2fLogo',
-                                'password2fUserCanRemoveKey',
-                                'password2fTTL',
-                            ]
-                        },
                         {
                             title => 'utotp2f',
                             help  => 'utotp2f.html',
@@ -979,6 +957,22 @@ sub tree {
                                 'u2fTTL'
                             ]
                         },
+                        {
+                            title => 'webauthn2f',
+                            help  => 'webauthn2f.html',
+                            form  => 'simpleInputContainer',
+                            nodes => [
+                                'webauthn2fActivation',
+                                'webauthn2fSelfRegistration',
+                                'webauthn2fUserVerification',
+                                'webauthn2fUserCanRemoveKey',
+                                'webauthnRpName',
+                                'webauthnDisplayNameAttr',
+                                'webauthn2fAuthnLevel',
+                                'webauthn2fLabel',
+                                'webauthn2fLogo',
+                            ]
+                        },
                         {
                             title => 'yubikey2f',
                             help  => 'yubikey2f.html',
@@ -999,6 +993,20 @@ sub tree {
                                 'yubikey2fTTL'
                             ],
                         },
+                        {
+                            title => 'password2f',
+                            help  => 'password2f.html',
+                            form  => 'simpleInputContainer',
+                            nodes => [
+                                'password2fActivation',
+                                'password2fSelfRegistration',
+                                'password2fAuthnLevel',
+                                'password2fLabel',
+                                'password2fLogo',
+                                'password2fUserCanRemoveKey',
+                                'password2fTTL',
+                            ]
+                        },
                         {
                             title => 'mail2f',
                             help  => 'mail2f.html',
@@ -1054,22 +1062,6 @@ sub tree {
                                 'rest2fLogo'
                             ]
                         },
-                        {
-                            title => 'webauthn2f',
-                            help  => 'webauthn2f.html',
-                            form  => 'simpleInputContainer',
-                            nodes => [
-                                'webauthn2fActivation',
-                                'webauthn2fSelfRegistration',
-                                'webauthn2fUserVerification',
-                                'webauthn2fUserCanRemoveKey',
-                                'webauthnRpName',
-                                'webauthnDisplayNameAttr',
-                                'webauthn2fAuthnLevel',
-                                'webauthn2fLabel',
-                                'webauthn2fLogo',
-                            ]
-                        },
                         'sfExtra',
                         {
                             title => 'sfRemovedNotification',
@@ -1138,6 +1130,15 @@ sub tree {
                                         'crowdsecUrl', 'crowdsecKey',
                                     ],
                                 },
+                                {
+                                    title => 'HIBPcheck',
+                                    help  => 'checkhibp.html',
+                                    form  => 'simpleInputContainer',
+                                    nodes => [
+                                        'checkHIBP', 'checkHIBPURL',
+                                        'checkHIBPRequired'
+                                    ],
+                                },
                                 {
                                     title => 'newLocationWarnings',
                                     help  => 'newlocationwarning.html',
@@ -1420,6 +1421,7 @@ sub tree {
                 'oidcServiceMetaDataIssuer',
                 {
                     title => 'oidcServiceMetaDataEndPoints',
+                    help  => 'openidconnectservice.html#endpoints',
                     form  => 'simpleInputContainer',
                     nodes => [
                         'oidcServiceMetaDataAuthorizeURI',
@@ -1437,6 +1439,7 @@ sub tree {
                 'oidcServiceMetaDataAuthnContext',
                 {
                     title => "oidcServiceDynamicRegistration",
+                    help  => 'openidconnectservice.html#dynamic-registration',
                     nodes => [
                         'oidcServiceAllowDynamicRegistration',
                         'oidcServiceDynamicRegistrationExportedVars',
@@ -1445,6 +1448,7 @@ sub tree {
                 },
                 {
                     title => 'oidcServiceMetaDataSecurity',
+                    help  => 'openidconnectservice.html#security',
                     nodes => [ {
                             title => 'oidcServiceMetaDataKeys',
                             form  => 'RSACertKeyNoPassword',
@@ -1457,12 +1461,13 @@ sub tree {
                         'oidcServiceAllowAuthorizationCodeFlow',
                         'oidcServiceAllowImplicitFlow',
                         'oidcServiceAllowHybridFlow',
-                        'oidcServiceAllowOnlyDeclaredScopes',
                         'oidcServiceIgnoreScopeForClaims',
+                        'oidcServiceAllowOnlyDeclaredScopes',
                     ],
                 },
                 {
                     title => 'oidcServiceMetaDataTimeouts',
+                    help  => 'openidconnectservice.html#timeouts',
                     form  => 'simpleInputContainer',
                     nodes => [
                         'oidcServiceAuthorizationCodeExpiration',
@@ -1473,6 +1478,7 @@ sub tree {
                 },
                 {
                     title => "oidcServiceMetaDataSessions",
+                    help  => 'openidconnectservice.html#sessions',
                     nodes => [ 'oidcStorage', 'oidcStorageOptions' ],
                 },
             ]
@@ -1483,14 +1489,10 @@ sub tree {
             title => 'casServiceMetadata',
             help  => 'idpcas.html#configuring-the-cas-service',
             nodes => [
-                'casAttr',
-                'casAccessControlPolicy',
-                'casStrictMatching',
-                'casTicketExpiration',
-                'casBackChannelSingleLogout',
-                'casStorage',
-                'casStorageOptions',
-                'casAttributes',
+                'casAttr',                    'casAccessControlPolicy',
+                'casStrictMatching',          'casTicketExpiration',
+                'casBackChannelSingleLogout', 'casStorage',
+                'casStorageOptions',          'casAttributes',
             ]
         },
         'casSrvMetaDataNodes',
